.. role:: hidden
    :class: hidden-section


botorch.generation
========================================================
.. automodule:: botorch.generation


Candidate Generation Utilities for Acquisition Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.generation.gen
    :members:


Sampling Strategies
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: botorch.generation.sampling
    :members:


Utilities
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: botorch.generation.utils
    :members:
